import { Item } from './components/Item.js';
import './components/CalculatedColumn.js';

const gridConfig = {
    store : {
        modelClass: Item,
        data       : [
            {
                category : 'Shirts',
                expanded : true,
                iconCls  : 'b-icon b-fa-tshirt',
                children : [
                    { name : 'Turtle neck', price : 55, iconCls : 'b-icon b-fa-tshirt', quantity : 12 },
                    { name : 'T-shirt', price : 35, iconCls : 'b-icon b-fa-tshirt', quantity : 4 },
                    { name : 'Long sleeve shirt', price : 40, iconCls : 'b-icon b-fa-tshirt', quantity : 2 }
                ]
            },
            {
                category : 'Mittens',
                expanded : true,
                iconCls  : 'b-icon b-fa-mitten',
                children : [
                    { name : 'Gant fur mittens', price : 155, iconCls : 'b-icon b-fa-mitten', quantity : 44 },
                    { name : 'Hestra insulated ski gloves', price : 135, iconCls : 'b-icon b-fa-mitten', quantity : 14 },
                    { name : 'Zara basic glove', price : 2, iconCls : 'b-icon b-fa-mitten', quantity : 22 }
                ]
            },
            {
                category : 'Hats',
                iconCls  : 'b-icon b-fa-hat-cowboy',
                expanded : true,
                children : [
                    { name : 'Baseball cap', price : 15, iconCls : 'b-icon b-fa-hat-cowboy', quantity : 44 },
                    { name : 'NY Yankees hat', price : 22, iconCls : 'b-icon b-fa-hat-cowboy', quantity : 15 },
                    { name : 'Woven hat', price : 5, iconCls : 'b-icon b-fa-hat-cowboy', quantity : 5 }
                ]
            }
        ]
    },
    features : {
        summary : true
    },
    columns : [
        {
            type            : 'tree',
            field           : 'category',
            editor          : false,
            minWidth        : 120,
            text            : 'Category',
            sum             : (sum, record) => sum + (record.isLeaf ? 0 : 1),
            summaryRenderer : ({ sum }) => `${sum} categories`
        },
        { field : 'name', text : 'Item', flex : 1 },
        {
            type   : 'aggregate',
            text   : 'Price',
            field  : 'price',
            flex   : 1,
            format : {
                locale      : 'en-US',
                template    : '$9,999',
                currency    : 'USD',
                significant : 5
            },
            sum : true
        },
        {
            type  : 'aggregate',
            text  : 'Quantity',
            field : 'quantity',
            flex  : 1,
            sum   : true
        },
        {
            id     : 'total',
            type   : 'calculated',
            text   : 'Total',
            flex   : 1,
            editor : false,
            format : {
                locale      : 'en-US',
                template    : '$9,999',
                currency    : 'USD',
                significant : 5
            },
            dependentFields : ['price', 'quantity'],
            field           : 'total', // A simple model getter function, see above
            sum             : (sum, record) => sum + (record.isLeaf ? record.total : 0)
        }
    ]
};

export { gridConfig };
