import { AggregateColumn, ColumnStore } from '@bryntum/grid';

// Define a custom column to use as the calculated "Total" column
export class CalculatedColumn extends AggregateColumn {
    static get type() {
        return 'calculated';
    }
    static get $name() {
        return 'CalculatedColumn';
    }
    static get fields() {
        return [
            // An array of fields the total column depends on
            'dependentFields'
        ];
    }

    get total() {
        return this.price * this.quantity;
    }

    construct() {
        super.construct(...arguments);

        this.grid.store.on({
            change  : this.onStoreChange,
            thisObj : this
        });
    }

    onStoreChange({ action, changes }) {
        // Only repaint this column if the dependent field data is updated
        if (action === 'update' && !this.dependentFields.some(field => field in changes)) {
            return;
        }
        this.grid.refreshColumn(this);
    }
}

ColumnStore.registerColumnType(CalculatedColumn);